@@ -1,11 +1,11 @@
+import binascii
+import enum
 import logging
 import struct
-import enum
-from io import BytesIO
-import bitstruct
-import binascii
 import traceback
+from io import BytesIO
 
+import bitstruct
 
 # Connection flags.
 CLEAN_START    = 0x02
@@ -720,18 +720,13 @@ def unpack_unsuback(payload):
     return packet_identifier, properties, reasons
 
 
-def pack_publish(topic, message, retain, alias):
+def pack_publish(topic, message, retain, properties):
     flags = 0
 
     if retain:
         flags |= 1
 
-    if alias is None:
-        properties = b'\x00'
-    else:
-        properties = pack_properties('PUBLISH',
-                                     {PropertyIds.TOPIC_ALIAS: alias})
-
+    properties = pack_properties('PUBLISH', properties)
     packed_topic = pack_string(topic)
     size = len(packed_topic) + len(message) + len(properties)
     packed = pack_fixed_header(ControlPacketType.PUBLISH, flags, size)
@@ -831,7 +826,6 @@ def format_publish(flags, payload):
         f'  Retain:     {retain}',
         f'  Topic:      {topic}',
         f'  Message:    {hexlify(message)}',
-        '  Properties:'
     ] + format_properties(properties)
 
 
@@ -859,7 +853,6 @@ def format_suback(payload):
 
     return [
         f'  PacketIdentifier: {packet_identifier}',
-        '  Properties:'
     ] + format_properties(properties) + [
         '  Reasons:'
     ] + [
@@ -881,7 +874,6 @@ def format_unsuback(payload):
 
     return [
         f'  PacketIdentifier: {packet_identifier}',
-        '  Properties:'
     ] + format_properties(properties) + [
         '  Reasons:'
     ] + [
@@ -894,7 +886,6 @@ def format_disconnect(payload):
 
     return [
         f'  Reason:     {reason.name}({reason.value})',
-        '  Properties:'
     ] + format_properties(properties)
 
 
