@@ -1,10 +1,12 @@
-import ssl
-import logging
 import asyncio
+import logging
+import ssl
 import unittest
 
 import mqttools
 
+from .utils import get_broker_address
+
 
 class BrokerTest(unittest.TestCase):
 
@@ -22,10 +24,9 @@ class BrokerTest(unittest.TestCase):
 
     async def multiple_subscribers(self):
         broker, broker_task = self.create_broker()
+        address = await get_broker_address(broker)
 
         async def tester():
-            address = await broker.getsockname()
-
             # Setup subscriber 1.
             reader_1, writer_1 = await asyncio.open_connection(*address)
             connect = b'\x10\x10\x00\x04MQTT\x05\x02\x00\x00\x00\x00\x03su1'
@@ -95,10 +96,9 @@ class BrokerTest(unittest.TestCase):
 
     async def subscribe_to_same_topic_twice(self):
         broker, broker_task = self.create_broker()
+        address = await get_broker_address(broker)
 
         async def tester():
-            address = await broker.getsockname()
-
             # Subscribe to "/a/b" and "/b/#" twice, all should be
             # successful. Subscribe to "/d/e" once.
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -179,10 +179,9 @@ class BrokerTest(unittest.TestCase):
 
     async def unsubscribe(self):
         broker, broker_task = self.create_broker()
+        address = await get_broker_address(broker)
 
         async def tester():
-            address = await broker.getsockname()
-
             # Setup the subscriber. Subscribe to /a/a, /a/b, /a/c and /a/d.
             reader_1, writer_1 = await asyncio.open_connection(*address)
             connect = b'\x10\x10\x00\x04MQTT\x05\x02\x00\x00\x00\x00\x03su1'
@@ -281,7 +280,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber and subscribe to
             # "sport/tennis/player1/#".
@@ -350,7 +349,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber and subscribe to "#".
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -397,7 +396,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber and subscribe to "+".
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -444,7 +443,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber and subscribe to "sport/+/player1".
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -491,7 +490,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber and subscribe to "sport/tennis/+".
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -553,7 +552,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber. Subscribe to a/# and b/+.
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -620,7 +619,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Try to resume a session that does not exist. A new
             # session should be created and immediately removed when
@@ -719,7 +718,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the pinger.
             reader, writer = await asyncio.open_connection(*address)
@@ -746,7 +745,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Connect with user name and password, and get 0x86 in
             # response.
@@ -772,7 +771,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Connect with authentication method, and get 0x8c in
             # response.
@@ -798,7 +797,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Send a publish packet instead of connect, nothing should
             # be received in response.
@@ -821,7 +820,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Malformed publish with property 0 should result in a
             # disconnect by the broker.
@@ -849,7 +848,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # It's a protocol error sending ping response to the
             # broker. should result in a disconnect by the broker.
@@ -877,7 +876,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Connect with maximum packet size set to 50.
             reader, writer = await asyncio.open_connection(*address)
@@ -928,7 +927,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber. Subscribe to 'foo' and 'a/#'.
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -1023,7 +1022,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup a publisher.
             reader_1, writer_1 = await asyncio.open_connection(*address)
@@ -1094,7 +1093,7 @@ class BrokerTest(unittest.TestCase):
         broker, broker_task = self.create_broker()
 
         async def tester():
-            address = await broker.getsockname()
+            address = await get_broker_address(broker)
 
             # Setup the subscriber. Subscribe to 'foo'.
             reader_1, writer_1 = await asyncio.open_connection(*address)
