@@ -1,11 +1,10 @@
-import logging
 import asyncio
-import unittest
+import logging
 import socket
+import unittest
 
 import mqttools
 
-
 BROKER_PORT = 10341
 
 
@@ -17,12 +16,12 @@ async def start_stop_clients():
     await subscriber.subscribe('/apa')
 
     await publisher.start()
-    publisher.publish('/apa', b'halloj')
+    publisher.publish(mqttools.Message('/apa', b'halloj'))
     await publisher.stop()
 
     message = await subscriber.messages.get()
 
-    if message != ('/apa', b'halloj'):
+    if message.topic != '/apa' or message.message != b'halloj':
         raise Exception('Wrong message {}'.format(message))
 
     await subscriber.stop()
